@@ -6,7 +6,10 @@
 #EJP--uncomment, so setMethod("[", etc ) and as(x, "data.frame") will work:
 #.noGenerics <- TRUE 
 
-.onLoad <- function(lib, pkg) require(methods)
+.onLoad <- function(lib, pkg) {
+	require(methods)
+}
+
 
 .onUnload <- function(libpath)
     library.dynam.unload("sp", libpath)
